Write a backend — Cohen3 0.8.0 documentation

# Write a backend

If you are interested in writing your own custom backend, then you could learn how to do it with those simple examples presented here. Currently you have two options, you can use the low level tools directly from backend or you could use the tools from models which will simplify a little the building process and you will end up with less lines of code, but by reading the first method you will get a better idea of what is happening behind the second method…so…you will have a better understanding of the Cohen3 tools by reading both:

> - Using backend directly - The old way
> - Using the models module - The new way